# RestCore [![CircleCI](https://circleci.com/gh/Roam-gg/RestCore/tree/develop.svg?style=svg)](https://circleci.com/gh/Roam-gg/RestCore/tree/develop) [![codecov](https://codecov.io/gh/Roam-gg/RestCore/branch/develop/graph/badge.svg)](https://codecov.io/gh/Roam-gg/RestCore)
This repository is designed to make developing REST API server, simpler.

